@@ -1,4 +1,6 @@
-# Copyright (C) 2014-2018 Internet Systems Consortium, Inc. ("ISC")
+#!/bin/sh
+
+# Copyright (C) 2014-2020 Internet Systems Consortium, Inc. ("ISC")
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -22,7 +24,9 @@ mysql_execute() {
         mysql -N -B "$@" -e "${QUERY}"
         retcode=$?
     else
-        mysql -N -B --database="${db_name}" --user="${db_user}" --password="${db_password}" -e "${QUERY}"
+        # Shellcheck complains about variables not being set. They're set in the script that calls this script.
+        # shellcheck disable=SC2154
+        mysql -N -B --host="${db_host}" --database="${db_name}" --user="${db_user}" --password="${db_password}" -e "${QUERY}"
         retcode=$?
     fi
 
@@ -36,7 +40,7 @@ mysql_execute_script() {
         mysql -N -B "$@" < "${file}"
         retcode=$?
     else
-        mysql -N -B --database="${db_name}" --user="${db_user}" --password="${db_password}" < "${file}"
+        mysql -N -B --host="${db_host}" --database="${db_name}" --user="${db_user}" --password="${db_password}" < "${file}"
         retcode=$?
     fi
 
@@ -48,6 +52,17 @@ mysql_version() {
     return $?
 }
 
+checked_mysql_version() {
+    mysql_execute "SELECT CONCAT_WS('.', version, minor) FROM schema_version" "$@"
+    retcode=$?
+    if [ $retcode -ne 0 ]
+    then
+        printf "Failed to get schema version, mysql status  %s\n" "${retcode}"
+        exit 1
+    fi
+    return $retcode
+}
+
 # Submits given SQL text to PostgreSQL
 # There are two ways of calling this method.
 # pgsql_execute SQL_QUERY - This call is simpler, but requires db_user,
@@ -62,11 +77,11 @@ pgsql_execute() {
     QUERY=$1
     shift
     if [ $# -gt 0 ]; then
-        echo "${QUERY}" | psql --set ON_ERROR_STOP=1 -A -t -h localhost -q "$@"
+        echo "${QUERY}" | psql --set ON_ERROR_STOP=1 -A -t -h "${db_host}" -q "$@"
         retcode=$?
     else
         export PGPASSWORD=$db_password
-        echo "${QUERY}" | psql --set ON_ERROR_STOP=1 -A -t -h localhost -q -U "${db_user}" -d "${db_name}"
+        echo "${QUERY}" | psql --set ON_ERROR_STOP=1 -A -t -h "${db_host}" -q -U "${db_user}" -d "${db_name}"
         retcode=$?
     fi
     return $retcode
@@ -86,11 +101,11 @@ pgsql_execute_script() {
     file=$1
     shift
     if [ $# -gt 0 ]; then
-        psql --set ON_ERROR_STOP=1 -A -t -h localhost -q -f "${file}" "$@"
+        psql --set ON_ERROR_STOP=1 -A -t -h "${db_host}" -q -f "${file}" "$@"
         retcode=$?
     else
         export PGPASSWORD=$db_password
-        psql --set ON_ERROR_STOP=1 -A -t -h localhost -q -U "${db_user}" -d "${db_name}" -f "${file}"
+        psql --set ON_ERROR_STOP=1 -A -t -h "${db_host}" -q -U "${db_user}" -d "${db_name}" -f "${file}"
         retcode=$?
     fi
     return $retcode
@@ -101,6 +116,17 @@ pgsql_version() {
     return $?
 }
 
+checked_pgsql_version() {
+    pgsql_execute "SELECT version || '.' || minor FROM schema_version" "$@"
+    retcode=$?
+    if [ $retcode -ne 0 ]
+    then
+        printf "Failed to get schema version, pgsql status %s\n" "${retcode}"
+        exit 1
+    fi
+    return $retcode
+}
+
 cql_execute() {
     query=$1
     shift
@@ -146,3 +172,27 @@ cql_version() {
     echo "$version"
     return $error
 }
+
+# recount IPv4 leases from scratch
+_RECOUNT4_QUERY=\
+"
+START TRANSACTION; \
+DELETE FROM lease4_stat; \
+INSERT INTO lease4_stat (subnet_id, state, leases) \
+    SELECT subnet_id, state, COUNT(*) \
+    FROM lease4 WHERE state = 0 OR state = 1 \
+    GROUP BY subnet_id, state; \
+COMMIT;"
+export _RECOUNT4_QUERY
+
+# recount IPv6 leases from scratch
+_RECOUNT6_QUERY=\
+"
+START TRANSACTION; \
+DELETE FROM lease6_stat; \
+INSERT INTO lease6_stat (subnet_id, lease_type, state, leases) \
+    SELECT subnet_id, lease_type, state, COUNT(*) \
+    FROM lease6 WHERE state = 0 OR state = 1 \
+    GROUP BY subnet_id, lease_type, state; \
+COMMIT;"
+export _RECOUNT6_QUERY
