@@ -116,6 +116,23 @@ public:
         cfg->setServerTag(server_tag);
     }
 
+    /// @brief Sets global parameters before other parameters are parsed.
+    ///
+    /// This method sets selected global parameters before other parameters
+    /// are parsed. This is important when the bahavior of the parsers
+    /// run later depends on these global paramters.
+    ///
+    /// Currently this method sets the following global parameters:
+    /// - ip-reservations-unique
+    ///
+    /// @param global global configuration scope
+    /// @param cfg Server configuration (parsed parameters will be stored here)
+    void parseEarly(const SrvConfigPtr& cfg, const ConstElementPtr& global) {
+        // Set ip-reservations-unique flag.
+        bool ip_reservations_unique = getBoolean(global, "ip-reservations-unique");
+        cfg->setIPReservationsUnique(ip_reservations_unique);
+    }
+
     /// @brief Copies subnets from shared networks to regular subnets container
     ///
     /// @param from pointer to shared networks container (copy from here)
@@ -368,6 +385,12 @@ configureDhcp4Server(Dhcpv4Srv& server, isc::data::ConstElementPtr config_set,
         // with the parser code debugability, so I decided to keep it as a
         // series of independent ifs.
 
+        // This parser is used in several places.
+        Dhcp4ConfigParser global_parser;
+
+        // Apply global options in the staging config, e.g. ip-reservations-unique
+        global_parser.parseEarly(srv_cfg, mutable_cfg);
+
         // We need definitions first
         ConstElementPtr option_defs = mutable_cfg->get("option-def");
         if (option_defs) {
@@ -504,9 +527,6 @@ configureDhcp4Server(Dhcpv4Srv& server, isc::data::ConstElementPtr config_set,
             }
         }
 
-        // This parser is used in several places.
-        Dhcp4ConfigParser global_parser;
-
         // Keep relative orders of shared networks and subnets.
         ConstElementPtr shared_networks = mutable_cfg->get("shared-networks");
         if (shared_networks) {
@@ -611,6 +631,8 @@ configureDhcp4Server(Dhcpv4Srv& server, isc::data::ConstElementPtr config_set,
                  (config_pair.first == "calculate-tee-times") ||
                  (config_pair.first == "t1-percent") ||
                  (config_pair.first == "t2-percent") ||
+                 (config_pair.first == "cache-threshold") ||
+                 (config_pair.first == "cache-max-age") ||
                  (config_pair.first == "loggers") ||
                  (config_pair.first == "hostname-char-set") ||
                  (config_pair.first == "hostname-char-replacement") ||
@@ -620,9 +642,12 @@ configureDhcp4Server(Dhcpv4Srv& server, isc::data::ConstElementPtr config_set,
                  (config_pair.first == "ddns-replace-client-name") ||
                  (config_pair.first == "ddns-generated-prefix") ||
                  (config_pair.first == "ddns-qualifying-suffix") ||
+                 (config_pair.first == "ddns-update-on-renew") ||
+                 (config_pair.first == "ddns-use-conflict-resolution") ||
                  (config_pair.first == "store-extended-info") ||
                  (config_pair.first == "statistic-default-sample-count") ||
-                 (config_pair.first == "statistic-default-sample-age")) {
+                 (config_pair.first == "statistic-default-sample-age") ||
+                 (config_pair.first == "ip-reservations-unique")) {
                 CfgMgr::instance().getStagingCfg()->addConfiguredGlobal(config_pair.first,
                                                                         config_pair.second);
                 continue;
