@@ -31,7 +31,6 @@ public:
         isc::Exception(file, line, what) { };
 };
 
-
 /// @brief Evaluation context, an interface to the expression evaluation.
 class Parser4Context
 {
@@ -150,10 +149,16 @@ public:
 
     /// @brief Error handler
     ///
+    /// @note The optional position for an error in a string begins by 1
+    /// so the caller should add 1 to the position of the C++ string.
+    ///
     /// @param loc location within the parsed file when experienced a problem.
     /// @param what string explaining the nature of the error.
+    /// @param pos optional position for in string errors.
     /// @throw Dhcp4ParseError
-    void error(const isc::dhcp::location& loc, const std::string& what);
+    void error(const isc::dhcp::location& loc,
+               const std::string& what,
+               size_t pos = 0);
 
     /// @brief Error handler
     ///
