@@ -132,6 +132,7 @@ public:
         subnet_->setDdnsQualifyingSuffix("example.com");
         subnet_->setHostnameCharSet("[^A-Za-z0-9-]");
         subnet_->setHostnameCharReplacement("x");
+        subnet_->setDdnsUseConflictResolution(true);
 
         ASSERT_NO_THROW(srv_->startD2());
     }
@@ -595,13 +596,15 @@ public:
     /// NameChangeRequest.
     /// @param fqdn The expected string value of the FQDN, if blank the
     /// check is skipped
+    /// @param exp_use_cr expected value of NCR::conflict_resolution_
     void verifyNameChangeRequest(const isc::dhcp_ddns::NameChangeType type,
                                  const bool reverse, const bool forward,
                                  const std::string& addr,
                                  const std::string& dhcid,
                                  const uint64_t expires,
                                  const uint16_t len,
-                                 const std::string& fqdn="") {
+                                 const std::string& fqdn = "",
+                                 const bool exp_use_cr = true) {
         NameChangeRequestPtr ncr;
         ASSERT_NO_THROW(ncr = d2_mgr_.peekAt(0));
         ASSERT_TRUE(ncr);
@@ -614,7 +617,10 @@ public:
             EXPECT_EQ(dhcid, ncr->getDhcid().toStr());
         }
 
-        EXPECT_EQ(expires, ncr->getLeaseExpiresOn());
+        if (expires != 0) {
+            EXPECT_EQ(expires, ncr->getLeaseExpiresOn());
+        }
+
         EXPECT_EQ(len, ncr->getLeaseLength());
         EXPECT_EQ(isc::dhcp_ddns::ST_NEW, ncr->getStatus());
 
@@ -622,6 +628,7 @@ public:
            EXPECT_EQ(fqdn, ncr->getFqdn());
         }
 
+        EXPECT_EQ(exp_use_cr, ncr->useConflictResolution());
 
         // Process the message off the queue
         ASSERT_NO_THROW(d2_mgr_.runReadyIO());
@@ -832,6 +839,39 @@ TEST_F(FqdnDhcpv6SrvTest, createNameChangeRequests) {
                             0, 500);
 }
 
+// Verify that conflict resolution is turned off when the
+// subnet has it disabled.
+TEST_F(FqdnDhcpv6SrvTest, noConflictResolution) {
+    // Create Reply message with Client Id and Server id.
+    Pkt6Ptr answer = generateMessageWithIds(DHCPV6_REPLY);
+
+    // Create three IAs, each having different address.
+    addIA(1234, IOAddress("2001:db8:1::1"), answer);
+
+    // Use domain name in upper case. It should be converted to lower-case
+    // before DHCID is calculated. So, we should get the same result as if
+    // we typed domain name in lower-case.
+    Option6ClientFqdnPtr fqdn = createClientFqdn(Option6ClientFqdn::FLAG_S,
+                                                 "MYHOST.EXAMPLE.COM",
+                                                 Option6ClientFqdn::FULL);
+    answer->addOption(fqdn);
+
+    // Create NameChangeRequest for the first allocated address.
+    AllocEngine::ClientContext6 ctx;
+    subnet_->setDdnsUseConflictResolution(false);
+    ctx.subnet_ = subnet_;
+    ctx.fwd_dns_update_ = ctx.rev_dns_update_ = true;
+    ASSERT_NO_THROW(srv_->createNameChangeRequests(answer, ctx));
+    ASSERT_EQ(1, d2_mgr_.getQueueSize());
+
+    // Verify that NameChangeRequest is correct.
+    verifyNameChangeRequest(isc::dhcp_ddns::CHG_ADD, true, true,
+                            "2001:db8:1::1",
+                            "000201415AA33D1187D148275136FA30300478"
+                            "FAAAA3EBD29826B5C907B2C9268A6F52",
+                            0, 500, "", false);
+}
+
 // Checks that NameChangeRequests to add entries are not
 // created when ddns updates are disabled.
 TEST_F(FqdnDhcpv6SrvTest, noAddRequestsWhenDisabled) {
@@ -1838,4 +1878,127 @@ TEST_F(FqdnDhcpv6SrvTest, ddnsSharedNetworkTest) {
     EXPECT_EQ("client1.one.example.com.", lease->hostname_);
 }
 
+// Verifies that renews only generate NCRs if the situation dictates
+// that it should. It checks:
+//
+// -# enable-updates true or false
+// -# update-on-renew true or false
+// -# Whether or not the FQDN has changed between old and new lease
+TEST_F(FqdnDhcpv6SrvTest, processRequestRenew) {
+    std::string fqdn1 = "one.example.com.";
+    std::string fqdn2 = "two.example.com.";
+    struct Scenario {
+        std::string description_;
+        bool send_updates_;
+        bool update_on_renew_;
+        std::string old_fqdn_;
+        std::string new_fqdn_;
+        size_t remove_;
+        size_t add_;
+    };
+
+    // Mnemonic constants.
+    const bool send_updates = true;
+    const bool update_on_renew = true;
+    const size_t remove = 1;
+    const size_t add = 1;
+
+    const std::vector<Scenario> scenarios = {
+        {
+        "#1 update-on-renew false, no change in fqdn",
+        send_updates, !update_on_renew, fqdn1, fqdn1, !remove, !add
+        },
+        {
+        "#2 update-on-renew is false, change in fqdn",
+        send_updates, !update_on_renew, fqdn1, fqdn2, remove, add
+        },
+        {
+        "#3 update-on-renew is true, no change in fqdn",
+        send_updates, update_on_renew, fqdn1, fqdn1, remove, add
+        },
+        {
+        "#4 update-on-renew is true, change in fqdn",
+        send_updates, update_on_renew, fqdn1, fqdn2, remove, add
+        },
+        // All prior scenarios test with send-updates true.  We really
+        // only need one with it false.
+        {
+        "#5 send-updates false, update-on-renew is true, change in fqdn",
+        !send_updates, update_on_renew, fqdn1, fqdn2, !remove, !add
+        }
+    };
+
+    enableD2();
+    subnet_->setDdnsReplaceClientNameMode(D2ClientConfig::RCM_NEVER);
+
+    // Iterate over test scenarios.
+    for (auto scenario : scenarios) {
+        SCOPED_TRACE(scenario.description_); {
+            // Make sure the lease does not exist.
+            ASSERT_FALSE(LeaseMgrFactory::instance().getLease6(Lease::TYPE_NA,
+                                          IOAddress("2001:db8:1:1::dead:beef")));
+            // Set and verify DDNS params flags
+            subnet_->setDdnsSendUpdates(scenario.send_updates_);
+            subnet_->setDdnsUpdateOnRenew(scenario.update_on_renew_);
+
+            ASSERT_EQ(scenario.send_updates_, getDdnsParams()->getEnableUpdates());
+            ASSERT_EQ(scenario.update_on_renew_, getDdnsParams()->getUpdateOnRenew());
+
+            // Create the "old" lease
+            testProcessMessage(DHCPV6_REQUEST, scenario.old_fqdn_, scenario.old_fqdn_);
+
+            // The lease should have been recorded in the database.
+            Lease6Ptr old_lease = LeaseMgrFactory::instance().getLease6(Lease::TYPE_NA,
+                                                     IOAddress("2001:db8:1:1::dead:beef"));
+            ASSERT_TRUE(old_lease);
+
+            if (!scenario.send_updates_ || scenario.old_fqdn_.empty()) {
+                // We should not have an NCR.
+                ASSERT_EQ(0, d2_mgr_.getQueueSize());
+            } else {
+                // We should have an NCR add.
+                ASSERT_EQ(1, d2_mgr_.getQueueSize());
+                verifyNameChangeRequest(isc::dhcp_ddns::CHG_ADD, true, true,
+                                        old_lease->addr_.toText(), "",
+                                        0, old_lease->valid_lft_,
+                                        old_lease->hostname_);
+            }
+
+            // Now let's renew (or create) the lease.
+            testProcessMessage(DHCPV6_RENEW, scenario.new_fqdn_, scenario.new_fqdn_);
+
+            // The lease should have been recorded in the database.
+            Lease6Ptr new_lease = LeaseMgrFactory::instance().getLease6(Lease::TYPE_NA,
+                                                   IOAddress("2001:db8:1:1::dead:beef"));
+            ASSERT_TRUE(new_lease);
+
+            // Verify queue count is correct.
+            ASSERT_EQ((scenario.remove_ + scenario.add_), d2_mgr_.getQueueSize());
+
+            // If we expect a remove, check it.
+            if (scenario.remove_ > 0) {
+                // Verify NCR content
+                verifyNameChangeRequest(isc::dhcp_ddns::CHG_REMOVE, true, true,
+                                        old_lease->addr_.toText(), "",
+                                        0, old_lease->valid_lft_,
+                                        old_lease->hostname_);
+            }
+
+            // If we expect an add, check it.
+            if (scenario.add_ > 0) {
+                // Verify NCR content
+                verifyNameChangeRequest(isc::dhcp_ddns::CHG_ADD, true, true,
+                                        new_lease->addr_.toText(), "",
+                                        0, new_lease->valid_lft_,
+                                        new_lease->hostname_);
+            }
+
+            // Now delete the lease.
+            bool deleted = false;
+            ASSERT_NO_THROW(deleted = LeaseMgrFactory::instance().deleteLease(new_lease));
+            ASSERT_TRUE(deleted);
+        }
+    }
+}
+
 } // end of anonymous namespace
