@@ -175,6 +175,7 @@ typedef boost::shared_ptr<TestCBControlDHCPv6> TestCBControlDHCPv6Ptr;
 /// @c CBControlDHCPv6 object.
 class NakedControlledDhcpv6Srv: public ControlledDhcpv6Srv {
 public:
+
     /// @brief Constructor.
     NakedControlledDhcpv6Srv()
         : ControlledDhcpv6Srv(0) {
@@ -399,6 +400,7 @@ TEST_F(JSONFileBackendTest, jsonFile) {
         " } ],"
         "\"valid-lifetime\": 4000 }"
         "}";
+
     writeFile(TEST_FILE, config);
 
     // Now initialize the server
@@ -416,66 +418,45 @@ TEST_F(JSONFileBackendTest, jsonFile) {
     ASSERT_TRUE(subnets);
     ASSERT_EQ(3, subnets->size()); // We expect 3 subnets.
 
-
     // Check subnet 1.
-    EXPECT_EQ("2001:db8:1::", subnets->at(0)->get().first.toText());
-    EXPECT_EQ(64, subnets->at(0)->get().second);
+    auto subnet = subnets->begin();
+    ASSERT_TRUE(subnet != subnets->end());
+    EXPECT_EQ("2001:db8:1::", (*subnet)->get().first.toText());
+    EXPECT_EQ(64, (*subnet)->get().second);
 
     // Check pools in the first subnet.
-    const PoolCollection& pools1 = subnets->at(0)->getPools(Lease::TYPE_NA);
+    const PoolCollection& pools1 = (*subnet)->getPools(Lease::TYPE_NA);
     ASSERT_EQ(1, pools1.size());
     EXPECT_EQ("2001:db8:1::", pools1.at(0)->getFirstAddress().toText());
     EXPECT_EQ("2001:db8:1::ffff:ffff:ffff", pools1.at(0)->getLastAddress().toText());
     EXPECT_EQ(Lease::TYPE_NA, pools1.at(0)->getType());
 
     // Check subnet 2.
-    EXPECT_EQ("2001:db8:2::", subnets->at(1)->get().first.toText());
-    EXPECT_EQ(64, subnets->at(1)->get().second);
+    ++subnet;
+    ASSERT_TRUE(subnet != subnets->end());
+    EXPECT_EQ("2001:db8:2::", (*subnet)->get().first.toText());
+    EXPECT_EQ(64, (*subnet)->get().second);
 
     // Check pools in the second subnet.
-    const PoolCollection& pools2 = subnets->at(1)->getPools(Lease::TYPE_NA);
+    const PoolCollection& pools2 = (*subnet)->getPools(Lease::TYPE_NA);
     ASSERT_EQ(1, pools2.size());
     EXPECT_EQ("2001:db8:2::", pools2.at(0)->getFirstAddress().toText());
     EXPECT_EQ("2001:db8:2::ffff:ffff:ffff", pools2.at(0)->getLastAddress().toText());
     EXPECT_EQ(Lease::TYPE_NA, pools2.at(0)->getType());
 
     // And finally check subnet 3.
-    EXPECT_EQ("2001:db8:3::", subnets->at(2)->get().first.toText());
-    EXPECT_EQ(64, subnets->at(2)->get().second);
+    ++subnet;
+    ASSERT_TRUE(subnet != subnets->end());
+    EXPECT_EQ("2001:db8:3::", (*subnet)->get().first.toText());
+    EXPECT_EQ(64, (*subnet)->get().second);
 
     // ... and it's only pool.
-    const PoolCollection& pools3 = subnets->at(2)->getPools(Lease::TYPE_NA);
+    const PoolCollection& pools3 = (*subnet)->getPools(Lease::TYPE_NA);
     EXPECT_EQ("2001:db8:3::", pools3.at(0)->getFirstAddress().toText());
     EXPECT_EQ("2001:db8:3::ffff:ffff:ffff", pools3.at(0)->getLastAddress().toText());
     EXPECT_EQ(Lease::TYPE_NA, pools3.at(0)->getType());
 }
 
-// This test verifies that the configurations for various servers
-// can coexist and that the DHCPv6 configuration parsers will simply
-// ignore them.
-TEST_F(JSONFileBackendTest, serverConfigurationsCoexistence) {
-    std::string config = "{ \"Dhcp6\": {"
-        "\"rebind-timer\": 2000, "
-        "\"renew-timer\": 1000, \n"
-        "\"preferred-lifetime\": 1000, \n"
-        "\"valid-lifetime\": 4000 }, "
-        "\"Dhcp4\": { },"
-        "\"DhcpDdns\": { },"
-        "\"Control-agent\": { }"
-        "}";
-
-    writeFile(TEST_FILE, config);
-
-    // Now initialize the server
-    boost::scoped_ptr<ControlledDhcpv6Srv> srv;
-    ASSERT_NO_THROW(
-        srv.reset(new ControlledDhcpv6Srv(0))
-    );
-
-    // And configure it using the config file.
-    EXPECT_NO_THROW(srv->init(TEST_FILE));
-}
-
 // This test checks if configuration can be read from a JSON file
 // using hash (#) line comments
 TEST_F(JSONFileBackendTest, hashComments) {
@@ -505,7 +486,7 @@ TEST_F(JSONFileBackendTest, hashComments) {
         srv.reset(new ControlledDhcpv6Srv(0))
     );
 
-    // And configure it using config without
+    // And configure it using config with comments.
     EXPECT_NO_THROW(srv->init(TEST_FILE));
 
     // Now check if the configuration has been applied correctly.
@@ -515,11 +496,13 @@ TEST_F(JSONFileBackendTest, hashComments) {
     ASSERT_EQ(1, subnets->size());
 
     // Check subnet 1.
-    EXPECT_EQ("2001:db8:1::", subnets->at(0)->get().first.toText());
-    EXPECT_EQ(64, subnets->at(0)->get().second);
+    auto subnet = subnets->begin();
+    ASSERT_TRUE(subnet != subnets->end());
+    EXPECT_EQ("2001:db8:1::", (*subnet)->get().first.toText());
+    EXPECT_EQ(64, (*subnet)->get().second);
 
     // Check pools in the first subnet.
-    const PoolCollection& pools1 = subnets->at(0)->getPools(Lease::TYPE_NA);
+    const PoolCollection& pools1 = (*subnet)->getPools(Lease::TYPE_NA);
     ASSERT_EQ(1, pools1.size());
     EXPECT_EQ("2001:db8:1::", pools1.at(0)->getFirstAddress().toText());
     EXPECT_EQ("2001:db8:1::ffff:ffff:ffff", pools1.at(0)->getLastAddress().toText());
@@ -555,7 +538,7 @@ TEST_F(JSONFileBackendTest, cppLineComments) {
         srv.reset(new ControlledDhcpv6Srv(0))
     );
 
-    // And configure it using config without
+    // And configure it using config with comments.
     EXPECT_NO_THROW(srv->init(TEST_FILE));
 
     // Now check if the configuration has been applied correctly.
@@ -565,11 +548,13 @@ TEST_F(JSONFileBackendTest, cppLineComments) {
     ASSERT_EQ(1, subnets->size());
 
     // Check subnet 1.
-    EXPECT_EQ("2001:db8:1::", subnets->at(0)->get().first.toText());
-    EXPECT_EQ(64, subnets->at(0)->get().second);
+    auto subnet = subnets->begin();
+    ASSERT_TRUE(subnet != subnets->end());
+    EXPECT_EQ("2001:db8:1::", (*subnet)->get().first.toText());
+    EXPECT_EQ(64, (*subnet)->get().second);
 
     // Check pools in the first subnet.
-    const PoolCollection& pools1 = subnets->at(0)->getPools(Lease::TYPE_NA);
+    const PoolCollection& pools1 = (*subnet)->getPools(Lease::TYPE_NA);
     ASSERT_EQ(1, pools1.size());
     EXPECT_EQ("2001:db8:1::", pools1.at(0)->getFirstAddress().toText());
     EXPECT_EQ("2001:db8:1::ffff:ffff:ffff", pools1.at(0)->getLastAddress().toText());
@@ -597,7 +582,7 @@ TEST_F(JSONFileBackendTest, cBlockComments) {
         "\"valid-lifetime\": 4000 }"
         "}";
 
-      writeFile(TEST_FILE, config_c_block_comments);
+    writeFile(TEST_FILE, config_c_block_comments);
 
     // Now initialize the server
     boost::scoped_ptr<ControlledDhcpv6Srv> srv;
@@ -605,7 +590,7 @@ TEST_F(JSONFileBackendTest, cBlockComments) {
         srv.reset(new ControlledDhcpv6Srv(0))
     );
 
-    // And configure it using config without
+    // And configure it using config with comments.
     EXPECT_NO_THROW(srv->init(TEST_FILE));
 
     // Now check if the configuration has been applied correctly.
@@ -615,11 +600,13 @@ TEST_F(JSONFileBackendTest, cBlockComments) {
     ASSERT_EQ(1, subnets->size());
 
     // Check subnet 1.
-    EXPECT_EQ("2001:db8:1::", subnets->at(0)->get().first.toText());
-    EXPECT_EQ(64, subnets->at(0)->get().second);
+    auto subnet = subnets->begin();
+    ASSERT_TRUE(subnet != subnets->end());
+    EXPECT_EQ("2001:db8:1::", (*subnet)->get().first.toText());
+    EXPECT_EQ(64, (*subnet)->get().second);
 
     // Check pools in the first subnet.
-    const PoolCollection& pools1 = subnets->at(0)->getPools(Lease::TYPE_NA);
+    const PoolCollection& pools1 = (*subnet)->getPools(Lease::TYPE_NA);
     ASSERT_EQ(1, pools1.size());
     EXPECT_EQ("2001:db8:1::", pools1.at(0)->getFirstAddress().toText());
     EXPECT_EQ("2001:db8:1::ffff:ffff:ffff", pools1.at(0)->getLastAddress().toText());
@@ -655,7 +642,7 @@ TEST_F(JSONFileBackendTest, include) {
         srv.reset(new ControlledDhcpv6Srv(0))
     );
 
-    // And configure it using config without
+    // And configure it using config with comments.
     EXPECT_NO_THROW(srv->init(TEST_FILE));
 
     // Now check if the configuration has been applied correctly.
@@ -665,11 +652,13 @@ TEST_F(JSONFileBackendTest, include) {
     ASSERT_EQ(1, subnets->size());
 
     // Check subnet 1.
-    EXPECT_EQ("2001:db8:1::", subnets->at(0)->get().first.toText());
-    EXPECT_EQ(64, subnets->at(0)->get().second);
+    auto subnet = subnets->begin();
+    ASSERT_TRUE(subnet != subnets->end());
+    EXPECT_EQ("2001:db8:1::", (*subnet)->get().first.toText());
+    EXPECT_EQ(64, (*subnet)->get().second);
 
     // Check pools in the first subnet.
-    const PoolCollection& pools1 = subnets->at(0)->getPools(Lease::TYPE_NA);
+    const PoolCollection& pools1 = (*subnet)->getPools(Lease::TYPE_NA);
     ASSERT_EQ(1, pools1.size());
     EXPECT_EQ("2001:db8:1::", pools1.at(0)->getFirstAddress().toText());
     EXPECT_EQ("2001:db8:1::ffff:ffff:ffff", pools1.at(0)->getLastAddress().toText());
@@ -699,14 +688,13 @@ TEST_F(JSONFileBackendTest, recursiveInclude) {
     writeFile(TEST_FILE, config_recursive_include);
     writeFile(TEST_INCLUDE, include);
 
-
     // Now initialize the server
     boost::scoped_ptr<ControlledDhcpv6Srv> srv;
     ASSERT_NO_THROW(
         srv.reset(new ControlledDhcpv6Srv(0))
     );
 
-    // And configure it using config
+    // And configure it using config with comments.
     try {
         srv->init(TEST_FILE);
         FAIL() << "Expected Dhcp6ParseError but nothing was raised";
@@ -716,7 +704,6 @@ TEST_F(JSONFileBackendTest, recursiveInclude) {
     }
 }
 
-// This test checks if configuration can be read from a JSON file.
 // This test checks if configuration detects failure when trying:
 // - empty file
 // - empty filename
@@ -907,7 +894,6 @@ TEST_F(JSONFileBackendTest, defaultLeaseDbBackend) {
     EXPECT_NO_THROW(static_cast<void>(LeaseMgrFactory::instance()));
 }
 
-
 // This test verifies that the timer triggering configuration updates
 // is invoked according to the configured value of the
 // config-fetch-wait-time.
@@ -970,7 +956,7 @@ public:
     ///
     /// Destroys MySQL schema.
     virtual ~JSONFileBackendMySQLTest() {
-        // If data wipe enabled, delete transient data otherwise destroy the schema
+        // If data wipe enabled, delete transient data otherwise destroy the schema.
         destroyMySQLSchema();
     }
 
