@@ -438,8 +438,10 @@ LeaseStatCmdsImpl::makeResultSet4(const ElementPtr& result_wrapper,
     }
 
     // Create the empty result-set.
-    std::vector<std::string>column_labels = { "subnet-id", "total-addreses",
-                                              "assigned-addreses","declined-addreses"};
+    std::vector<std::string>column_labels = { "subnet-id", "total-addresses",
+                                              "cumulative-assigned-addresses",
+                                              "assigned-addresses",
+                                              "declined-addresses" };
     ElementPtr value_rows = createResultSet(result_wrapper, column_labels);
 
     // Get the first query row
@@ -531,8 +533,12 @@ LeaseStatCmdsImpl::makeResultSet6(const ElementPtr& result_wrapper,
 
     // Create the result-set map.
     // labels could be class statics?
-    std::vector<std::string>column_labels = { "subnet-id", "total-nas", "assigned-nas",
-                                              "declined-nas", "total-pds", "assigned-pds"};
+    std::vector<std::string>column_labels = { "subnet-id", "total-nas",
+                                              "cumulative-assigned-nas",
+                                              "assigned-nas",
+                                              "declined-nas", "total-pds",
+                                              "cumulative-assigned-pds",
+                                              "assigned-pds" };
     ElementPtr value_rows = createResultSet(result_wrapper, column_labels);
 
     // Now we can run the stats query.
@@ -634,6 +640,7 @@ LeaseStatCmdsImpl::addValueRow4(ElementPtr value_rows, const SubnetID &subnet_id
     ElementPtr row = Element::createList();
     row->add(Element::create(static_cast<int64_t>(subnet_id)));
     row->add(Element::create(getSubnetStat(subnet_id, "total-addresses")));
+    row->add(Element::create(getSubnetStat(subnet_id, "cumulative-assigned-addresses")));
     row->add(Element::create(assigned));
     row->add(Element::create(declined));
     value_rows->add(row);
@@ -645,9 +652,11 @@ LeaseStatCmdsImpl::addValueRow6(ElementPtr value_rows, const SubnetID &subnet_id
     ElementPtr row = Element::createList();
     row->add(Element::create(static_cast<int64_t>(subnet_id)));
     row->add(Element::create(getSubnetStat(subnet_id, "total-nas")));
+    row->add(Element::create(getSubnetStat(subnet_id, "cumulative-assigned-nas")));
     row->add(Element::create(assigned));
     row->add(Element::create(declined));
     row->add(Element::create(getSubnetStat(subnet_id, "total-pds")));
+    row->add(Element::create(getSubnetStat(subnet_id, "cumulative-assigned-pds")));
     row->add(Element::create(assigned_pds));
     value_rows->add(row);
 }
