@@ -180,6 +180,23 @@ BaseNetworkParser::parseTeePercents(const ConstElementPtr& network_data,
     network->setT1Percent(t1_percent);
 }
 
+void
+BaseNetworkParser::parseCacheParams(const ConstElementPtr& network_data,
+                                    NetworkPtr& network) {
+    if (network_data->contains("cache-threshold")) {
+        double cache_threshold = getDouble(network_data, "cache-threshold");
+        if ((cache_threshold <= 0.0) || (cache_threshold >= 1.0)) {
+            isc_throw(DhcpConfigError, "cache-threshold: " << cache_threshold
+                      << " is invalid, it must be greater than 0.0 and less than 1.0");
+        }
+        network->setCacheThreshold(cache_threshold);
+    }
+
+    if (network_data->contains("cache-max-age")) {
+        network->setCacheMaxAge(getInteger(network_data, "cache-max-age"));
+    }
+}
+
 void
 BaseNetworkParser::parseHostReservationMode(const data::ConstElementPtr& network_data,
                                             NetworkPtr& network) {
@@ -250,6 +267,14 @@ BaseNetworkParser::parseDdnsParams(const data::ConstElementPtr& network_data,
                       << "' is not a valid regular expression");
         }
     }
+
+    if (network_data->contains("ddns-update-on-renew")) {
+        network->setDdnsUpdateOnRenew(getBoolean(network_data, "ddns-update-on-renew"));
+    }
+
+    if (network_data->contains("ddns-use-conflict-resolution")) {
+        network->setDdnsUseConflictResolution(getBoolean(network_data, "ddns-use-conflict-resolution"));
+    }
 }
 
 } // end of namespace isc::dhcp
