@@ -192,6 +192,9 @@ SharedNetwork4Parser::parse(const data::ConstElementPtr& shared_network_data) {
 
         // Parse DDNS parameters
         parseDdnsParams(shared_network_data, network);
+
+        // Parse lease cache parameters
+        parseCacheParams(shared_network_data, network);
     } catch (const DhcpConfigError&) {
         // Position was already added
         throw;
@@ -355,6 +358,9 @@ SharedNetwork6Parser::parse(const data::ConstElementPtr& shared_network_data) {
 
         // Parse DDNS parameters
         parseDdnsParams(shared_network_data, network);
+
+        // Parse lease cache parameters
+        parseCacheParams(shared_network_data, network);
     } catch (const std::exception& ex) {
         isc_throw(DhcpConfigError, ex.what() << " ("
                   << shared_network_data->getPosition() << ")");
