@@ -86,7 +86,12 @@ const SimpleKeywords SimpleParser4::GLOBAL4_PARAMETERS = {
     { "store-extended-info",            Element::boolean },
     { "statistic-default-sample-count", Element::integer },
     { "statistic-default-sample-age",   Element::integer },
-    { "multi-threading",                Element::map }
+    { "multi-threading",                Element::map },
+    { "cache-threshold",                Element::real },
+    { "cache-max-age",                  Element::integer },
+    { "ip-reservations-unique",         Element::boolean },
+    { "ddns-update-on-renew",           Element::boolean },
+    { "ddns-use-conflict-resolution",   Element::boolean }
 };
 
 /// @brief This table defines default global values for DHCPv4
@@ -119,7 +124,10 @@ const SimpleDefaults SimpleParser4::GLOBAL4_DEFAULTS = {
     { "hostname-char-replacement",      Element::string,  "" },
     { "store-extended-info",            Element::boolean, "false" },
     { "statistic-default-sample-count", Element::integer, "20" },
-    { "statistic-default-sample-age",   Element::integer, "0" }
+    { "statistic-default-sample-age",   Element::integer, "0" },
+    { "ip-reservations-unique",         Element::boolean, "true" },
+    { "ddns-update-on-renew",           Element::boolean, "false" },
+    { "ddns-use-conflict-resolution",   Element::boolean, "true" }
 };
 
 /// @brief This table defines all option definition parameters.
@@ -146,7 +154,7 @@ const SimpleKeywords SimpleParser4::OPTION4_DEF_PARAMETERS = {
 /// definitions. This array lists default values for those option definitions.
 const SimpleDefaults SimpleParser4::OPTION4_DEF_DEFAULTS = {
     { "record-types", Element::string,  ""},
-    { "space",        Element::string,  "dhcp4"},
+    { "space",        Element::string,  "dhcp4"}, // DHCP4_OPTION_SPACE
     { "array",        Element::boolean, "false"},
     { "encapsulate",  Element::string,  "" }
 };
@@ -174,7 +182,7 @@ const SimpleKeywords SimpleParser4::OPTION4_PARAMETERS = {
 /// subnet, class or host reservations scopes. This array lists default values
 /// for those option-data declarations.
 const SimpleDefaults SimpleParser4::OPTION4_DEFAULTS = {
-    { "space",        Element::string,  "dhcp4"},
+    { "space",        Element::string,  "dhcp4"}, // DHCP4_OPTION_SPACE
     { "csv-format",   Element::boolean, "true"},
     { "always-send",  Element::boolean, "false"}
 };
@@ -222,7 +230,11 @@ const SimpleKeywords SimpleParser4::SUBNET4_PARAMETERS = {
     { "hostname-char-set",              Element::string },
     { "hostname-char-replacement",      Element::string },
     { "store-extended-info",            Element::boolean },
-    { "metadata",                       Element::map }
+    { "metadata",                       Element::map },
+    { "cache-threshold",                Element::real },
+    { "cache-max-age",                  Element::integer },
+    { "ddns-update-on-renew",           Element::boolean },
+    { "ddns-use-conflict-resolution",   Element::boolean }
 };
 
 /// @brief This table defines default values for each IPv4 subnet.
@@ -273,7 +285,9 @@ const ParamsList SimpleParser4::INHERIT_TO_SUBNET4 = {
     "calculate-tee-times",
     "t1-percent",
     "t2-percent",
-    "store-extended-info"
+    "store-extended-info",
+    "cache-threshold",
+    "cache-max-age"
 };
 
 /// @brief This table defines all pool parameters.
@@ -329,7 +343,11 @@ const SimpleKeywords SimpleParser4::SHARED_NETWORK4_PARAMETERS = {
     { "hostname-char-set",              Element::string },
     { "hostname-char-replacement",      Element::string },
     { "store-extended-info",            Element::boolean },
-    { "metadata",                       Element::map }
+    { "metadata",                       Element::map },
+    { "cache-threshold",                Element::real },
+    { "cache-max-age",                  Element::integer },
+    { "ddns-update-on-renew",           Element::boolean },
+    { "ddns-use-conflict-resolution",   Element::boolean }
 };
 
 /// @brief This table defines default values for each IPv4 shared network.
@@ -347,7 +365,7 @@ const SimpleDefaults SimpleParser4::IFACE4_DEFAULTS = {
 const SimpleDefaults SimpleParser4::DHCP_QUEUE_CONTROL4_DEFAULTS = {
     { "enable-queue",   Element::boolean, "false"},
     { "queue-type",     Element::string,  "kea-ring4"},
-    { "capacity",       Element::integer, "500"}
+    { "capacity",       Element::integer, "64"}
 };
 
 /// @brief This table defines default values for multi-threading in DHCPv4.
