@@ -16,10 +16,12 @@ namespace db {
 ///
 //@{
 
-#ifdef HAVE_MYSQL_MY_BOOL
 /// @brief my_bools type for vectors.
-typedef my_bool my_bools;
+/// @note vector<bool> is specialized into a bitset, so vector<char>
+/// must be used instead
+typedef char my_bools;
 
+#ifdef HAVE_MYSQL_MY_BOOL
 /// @brief MySQL false value.
 const my_bool MLM_FALSE = 0;
 
@@ -30,10 +32,6 @@ const my_bool MLM_TRUE = 1;
 /// @brief my_bool type in MySQL 8.x.
 typedef bool my_bool;
 
-/// @brief my_bools type for vectors in MySQL 8.x.
-/// @note vector<my_bool> is specialized into a bitset.
-typedef char my_bools;
-
 /// @brief MySQL false value.
 const my_bool MLM_FALSE = false;
 
@@ -41,6 +39,9 @@ const my_bool MLM_FALSE = false;
 const my_bool MLM_TRUE = true;
 #endif
 
+///@brief check for bool size
+static_assert(sizeof(my_bool) == sizeof(char), "unsupported bool size");
+
 /// @brief MySQL fetch success code.
 const int MLM_MYSQL_FETCH_SUCCESS = 0;
 
@@ -52,7 +53,7 @@ const int MLM_MYSQL_FETCH_FAILURE = 0;
 /// @name Current database schema version values.
 //@{
 const uint32_t MYSQL_SCHEMA_VERSION_MAJOR = 9;
-const uint32_t MYSQL_SCHEMA_VERSION_MINOR = 1;
+const uint32_t MYSQL_SCHEMA_VERSION_MINOR = 4;
 
 //@}
 
