@@ -17,9 +17,9 @@
 namespace isc {
 namespace db {
 
-/// @brief Define PostgreSQL backend version: 6.1
+/// @brief Define PostgreSQL backend version: 6.2
 const uint32_t PG_SCHEMA_VERSION_MAJOR = 6;
-const uint32_t PG_SCHEMA_VERSION_MINOR = 1;
+const uint32_t PG_SCHEMA_VERSION_MINOR = 2;
 
 // Maximum number of parameters that can be used a statement
 // @todo This allows us to use an initializer list (since we can't
@@ -411,7 +411,7 @@ public:
     ///
     /// @throw isc::db::DbOperationError Detailed PostgreSQL failure
     void checkStatementError(const PgSqlResult& r,
-                             PgSqlTaggedStatement& statement) const;
+                             PgSqlTaggedStatement& statement);
 
     /// @brief PgSql connection handle
     ///
