@@ -18,7 +18,7 @@ prefix=/usr/locala
 if [ -e ${prefix}/share/kea/scripts/admin-utils.sh ]; then
     . ${prefix}/share/kea/scripts/admin-utils.sh
 else
-    . /home/jenkins/workspace/kea-1.8/tarball-internal/kea/src/bin/admin/admin-utils.sh
+    . /home/jenkins/workspace/kea-dev/tarball-internal/kea/src/bin/admin/admin-utils.sh
 fi
 
 # First argument is must be the expected schema version <major>.<minor>
