@@ -11,64 +11,24 @@ fi
 
 VERSION=`pgsql_version "$@"`
 
-if [ "$VERSION" != "1.0" ]; then
-    printf "This script upgrades 1.0 to 2.0. Reported version is $VERSION. Skipping upgrade.\n"
+if [ "$VERSION" != "4.0" ]; then
+    printf "This script upgrades 4.0 to 5.0. Reported version is $VERSION. Skipping upgrade.\n"
     exit 0
 fi
 
 psql "$@" >/dev/null <<EOF
--- Add state column to the lease4 table.
-ALTER TABLE lease4
-    ADD COLUMN state INT8 DEFAULT 0;
 
--- Add state column to the lease6 table.
-ALTER TABLE lease6
-    ADD COLUMN state INT8 DEFAULT 0;
-
--- Create indexes for querying leases in a given state and segregated
--- by the expiration time. One of the applications is to retrieve all
--- expired leases. However, these indexes can be also used to retrieve
--- leases in a given state regardless of the expiration time.
-CREATE INDEX lease4_by_state_expire ON lease4 (state ASC, expire ASC);
-CREATE INDEX lease6_by_state_expire ON lease6 (state ASC, expire ASC);
-
--- Create table holding mapping of the lease states to their names.
--- This is not used in queries from the DHCP server but rather in
--- direct queries from the lease database management tools.
-CREATE TABLE lease_state (
-    state INT8 PRIMARY KEY NOT NULL,
-    name VARCHAR(64) NOT NULL);
-
--- Insert currently defined state names.
 START TRANSACTION;
-INSERT INTO lease_state VALUES (0, 'default');
-INSERT INTO lease_state VALUES (1, 'declined');
-INSERT INTO lease_state VALUES (2, 'expired-reclaimed');
-COMMIT;
 
--- Add a constraint that any state value added to the lease4 must
--- map to a value in the lease_state table.
-ALTER TABLE lease4
-    ADD CONSTRAINT fk_lease4_state FOREIGN KEY (state)
-    REFERENCES lease_state (state);
-
--- Add a constraint that any state value added to the lease6 must
--- map to a value in the lease_state table.
-ALTER TABLE lease6
-    ADD CONSTRAINT fk_lease6_state FOREIGN KEY (state)
-    REFERENCES lease_state (state);
-
--- Add a constraint that lease type in the lease6 table must map
--- to a lease type defined in the lease6_types table.
-ALTER TABLE lease6
-    ADD CONSTRAINT fk_lease6_type FOREIGN KEY (lease_type)
-    REFERENCES lease6_types (lease_type);
+-- Add a column holding leases for user context.
+ALTER TABLE lease4 ADD COLUMN user_context TEXT;
+ALTER TABLE lease6 ADD COLUMN user_context TEXT;
 
 --
 --  FUNCTION that returns a result set containing the column names for lease4 dumps
 DROP FUNCTION IF EXISTS lease4DumpHeader();
 CREATE FUNCTION lease4DumpHeader() RETURNS text AS  \$\$
-    select cast('address,hwaddr,client_id,valid_lifetime,expire,subnet_id,fqdn_fwd,fqdn_rev,hostname,state' as text) as result;
+    select cast('address,hwaddr,client_id,valid_lifetime,expire,subnet_id,fqdn_fwd,fqdn_rev,hostname,state,user_context' as text) as result;
 \$\$ LANGUAGE SQL;
 --
 
@@ -85,7 +45,8 @@ CREATE FUNCTION lease4DumpData() RETURNS
            fqdn_fwd int,
            fqdn_rev int,
            hostname text,
-           state text
+           state text,
+           user_context text
     ) as \$\$
     SELECT ('0.0.0.0'::inet + l.address),
             encode(l.hwaddr,'hex'),
@@ -96,9 +57,11 @@ CREATE FUNCTION lease4DumpData() RETURNS
             l.fqdn_fwd::int,
             l.fqdn_rev::int,
             l.hostname,
-            s.name
+            s.name,
+            l.user_context
     FROM lease4 l
-         left outer join lease_state s on (l.state = s.state);
+         left outer join lease_state s on (l.state = s.state)
+    ORDER BY l.address;
 \$\$ LANGUAGE SQL;
 --
 
@@ -106,7 +69,7 @@ CREATE FUNCTION lease4DumpData() RETURNS
 --  FUNCTION that returns a result set containing the column names for lease6 dumps
 DROP FUNCTION IF EXISTS lease6DumpHeader();
 CREATE FUNCTION lease6DumpHeader() RETURNS text AS  \$\$
-    select cast('address,duid,valid_lifetime,expire,subnet_id,pref_lifetime,lease_type,iaid,prefix_len,fqdn_fwd,fqdn_rev,hostname,state' as text) as result;
+    select cast('address,duid,valid_lifetime,expire,subnet_id,pref_lifetime,lease_type,iaid,prefix_len,fqdn_fwd,fqdn_rev,hostname,state,hwaddr,hwtype,hwaddr_source,user_context' as text) as result;
 \$\$ LANGUAGE SQL;
 --
 
@@ -127,7 +90,11 @@ CREATE FUNCTION lease6DumpData() RETURNS
            fqdn_fwd int,
            fqdn_rev int,
            hostname text,
-           state text
+           state text,
+           hwaddr text,
+           hwtype smallint,
+           hwaddr_source text,
+           user_context text
     ) AS \$\$
     SELECT (l.address,
             encode(l.duid,'hex'),
@@ -141,18 +108,51 @@ CREATE FUNCTION lease6DumpData() RETURNS
             l.fqdn_fwd::int,
             l.fqdn_rev::int,
             l.hostname,
-            s.name)
+            s.name,
+            encode(l.hwaddr,'hex'),
+            l.hwtype,
+            h.name,
+            l.user_context
+     )
      FROM lease6 l
          left outer join lease6_types t on (l.lease_type = t.lease_type)
-         left outer join lease_state s on (l.state = s.state);
+         left outer join lease_state s on (l.state = s.state)
+         left outer join lease_hwaddr_source h on (l.hwaddr_source = h.hwaddr_source)
+     ORDER BY l.address;
 \$\$ LANGUAGE SQL;
 --
 
--- Set 2.0 schema version.
-START TRANSACTION;
+-- Create logs table (logs table is used by forensic logging hook library)
+CREATE TABLE logs (
+    timestamp TIMESTAMP WITH TIME ZONE
+    DEFAULT CURRENT_TIMESTAMP,          -- creation timestamp
+    address VARCHAR(43) NULL,           -- address or prefix
+    log TEXT NOT NULL                   -- the log itself
+    );
+
+-- Create search indexes
+CREATE INDEX timestamp_id ON logs (timestamp);
+CREATE INDEX address_id ON logs (address);
+
+-- Create auth_key in hosts table for storing keys for DHCPv6 reconfigure.
+ALTER TABLE hosts ADD COLUMN auth_key  VARCHAR(16) DEFAULT NULL;
+
+-- Convert subnet-id values of 0  to NULL
+UPDATE hosts SET dhcp4_subnet_id = NULL WHERE dhcp4_subnet_id = 0;
+UPDATE dhcp4_options SET dhcp4_subnet_id = NULL WHERE dhcp4_subnet_id = 0;
+UPDATE hosts SET dhcp6_subnet_id = NULL WHERE dhcp6_subnet_id = 0;
+UPDATE dhcp6_options SET dhcp6_subnet_id = NULL WHERE dhcp6_subnet_id = 0;
+
+-- Set 5.0 schema version.
 UPDATE schema_version
-    SET version = '2', minor = '0';
+    SET version = '5', minor = '0';
+
+-- Schema 5.0 specification ends here.
+
+-- Commit the script transaction
 COMMIT;
+
 EOF
 
 exit $RESULT
+
